@@ -23,8 +23,12 @@
 #ifndef _LIBNFS_H_
 #define _LIBNFS_H_
 
+#ifdef PS2_EE
+#include "ps2_compat.h"
+#endif
+
 #include <stdint.h>
-#if defined(__ANDROID__) || defined(AROS) \
+#if defined(__ANDROID__) || defined(AROS) || defined(__PPU__) \
  || ( defined(__APPLE__) && defined(__MACH__) )
 #include <sys/time.h>
 #else
@@ -41,6 +45,9 @@ extern "C" {
 #define LIBNFS_FEATURE_READAHEAD
 #define LIBNFS_FEATURE_PAGECACHE
 #define LIBNFS_FEATURE_DEBUG
+#define LIBNFS_FEATURE_UMOUNT
+#define LIBNFS_FEATURE_MULTITHREADING
+
 #define NFS_BLKSIZE 4096
 #define NFS_PAGECACHE_DEFAULT_TTL 5
 
@@ -53,7 +60,7 @@ struct nfs_url {
 	char *file;
 };
 
-#if defined(WIN32)
+#if defined(WIN32) && defined(libnfs_EXPORTS)
 #define EXTERN __declspec( dllexport )
 #else
 #ifndef EXTERN
@@ -247,15 +254,25 @@ EXTERN void nfs_destroy_url(struct nfs_url *url);
 struct nfsfh;
 
 /*
- * Get the maximum supported READ3 size by the server
+ * Get the maximum supported READ size by the server
  */
 EXTERN uint64_t nfs_get_readmax(struct nfs_context *nfs);
 
 /*
- * Get the maximum supported WRITE3 size by the server
+ * Get the maximum supported WRITE size by the server
  */
 EXTERN uint64_t nfs_get_writemax(struct nfs_context *nfs);
 
+/*
+ * Set the maximum supported READ size by the server
+ */
+EXTERN void nfs_set_readmax(struct nfs_context *nfs, uint64_t readmax);
+
+/*
+ * Set the maximum supported WRITE size by the server
+ */
+EXTERN void nfs_set_writemax(struct nfs_context *nfs, uint64_t writemax);
+        
 /*
  *  MODIFY CONNECT PARAMETERS
  */
@@ -276,6 +293,12 @@ EXTERN void nfs_set_autoreconnect(struct nfs_context *nfs, int num_retries);
  * NFS_V4
  */
 EXTERN int nfs_set_version(struct nfs_context *nfs, int version);
+/*
+ * Get NFS version of a connected share. Supported versions are
+ * NFS_V3
+ * NFS_V4
+ */
+EXTERN int nfs_get_version(struct nfs_context *nfs);
 
 /*
  *  Invalidate the pagecache
@@ -1905,6 +1928,16 @@ EXTERN int mount_getexports_async(struct rpc_context *rpc, const char *server,
  */
 EXTERN struct exportnode *mount_getexports(const char *server);
 
+/*
+ * Sync getexports_timeout(<server>, <timeout>)
+ * Function returns
+ *            NULL : something failed
+ *  exports export : a linked list of exported directories
+ *
+ * returned data must be freed by calling mount_free_export_list(exportnode);
+ */
+EXTERN struct exportnode *mount_getexports_timeout(const char *server, int timeout);
+
 EXTERN void mount_free_export_list(struct exportnode *exports);
 
 
@@ -1962,6 +1995,20 @@ EXTERN void nfs4_set_client_name(struct nfs_context *nfs, const char *id);
  */
 EXTERN void nfs4_set_verifier(struct nfs_context *nfs, const char *verifier);
 
+/*
+ * MULTITHREADING
+ */        
+/*
+ * This function starts a separate service thread for multithreading support.
+ * When multithreading is enabled the eventdriven async API is no longer
+ * supported and you can only use the synchronous API.
+ */
+EXTERN int nfs_mt_service_thread_start(struct nfs_context *nfs);
+/*
+ * Shutdown multithreading support.
+ */
+EXTERN void nfs_mt_service_thread_stop(struct nfs_context *nfs);
+        
 #ifdef __cplusplus
 }
 #endif
